@@ -4,7 +4,7 @@ from typing import Dict, List, Optional, Union
 from uuid import uuid4
 
 import numpy as np
-from scipy.special import softmax
+from scipy.special import expit, softmax
 
 from dataquality import config
 from dataquality.exceptions import GalileoException
@@ -60,10 +60,17 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
             get_stdout_logger().exception(
                 "Logging of model outputs failed", split=self.split, epoch=self.epoch
             )
-            warnings.warn(f"An issue occurred while logging: {str(e)}")
+            err_msg = (
+                f"An issue occurred while logging model outputs. Address any issues in "
+                f"your logging and make sure to call dq.init before restarting:\n"
+                f"{str(e)}"
+            )
+            warnings.warn(err_msg)
+            self.logger_config.exception = err_msg
 
     def log(self) -> None:
-        """The top level log function that try/excepts it's child"""
+        """The top level log function that try/excepts its child"""
+        self.check_for_logging_failures()
         # We validate split and epoch before entering the thread because we reference
         # global variables (cur_split and cur_epoch) that are subject to change
         # between subsequent threads
@@ -139,6 +146,18 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
     def _get_data_dict(self) -> Dict:
         """Constructs a dictionary of arrays from logged model output data"""
 
+    def convert_logits_to_prob_binary(self, sample_logits: np.ndarray) -> np.ndarray:
+        """Converts logits to probs in the binary case
+
+        Takes the sigmoid of the single class logits and adds the negative
+        lass prediction (1-class pred)
+        """
+        sample_probs = expit(sample_logits)
+        probs_1 = np.expand_dims(sample_probs, axis=-1)
+        probs_0 = 1 - probs_1
+        probs = np.concatenate([probs_0, probs_1], axis=-1)
+        return probs
+
     def convert_logits_to_probs(
         self, sample_logits: Union[List[np.ndarray], np.ndarray]
     ) -> np.ndarray:
@@ -147,4 +166,9 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
         # we take the softmax for each sample
         if not isinstance(sample_logits, np.ndarray):
             sample_logits = self._convert_tensor_ndarray(sample_logits)
+        if len(sample_logits.shape) == 1 or sample_logits.shape[1] == 1:
+            if len(sample_logits.shape) > 1:
+                # Remove final empty dimension if it's there
+                sample_logits = sample_logits.reshape(-1)
+            return self.convert_logits_to_prob_binary(sample_logits)
         return softmax(np.array(sample_logits), axis=-1)
